@@ -12,7 +12,7 @@
 #include "crc.hpp"
 #include "specache.hpp"
 
-#ifndef __POWERPC__
+#if (defined(__MACH__) || !defined(__APPLE__))
 #include <sys/stat.h>
 #endif
 
@@ -664,50 +664,52 @@ extern char *macify_name(char *s);
 
 void cache_list::create_lcache()
 {
-#ifdef __WATCOMC__
-  char *prefix="c:\\";
+#ifdef WIN32
+	char *prefix="c:\\";
 #else
-  char *prefix="/tmp/";     // for UNIX store lisp cache in tmp dir
-  int flags=O_CREAT | O_RDWR;
+	char *prefix="/tmp/";     // for UNIX store lisp cache in tmp dir
+	int flags=O_CREAT | O_RDWR;
 #endif
- 
-  int cfail=1,num=0;
-  do
-  {
-    sprintf(lfname,"%slcache%02d.tmp",prefix,num);
 
-#if defined( __WATCOMC__ ) || defined( __POWERPC__ )
-    unlink(lfname);
-#ifdef __POWERPC__
+	int cfail = 1, num = 0;
+	do
+	{
+		sprintf(lfname,"%slcache%02d.tmp",prefix,num);
+
+#if defined( __APPLE__ )
+		unlink(lfname);
+#if (defined(__APPLE__) && !defined(__MACH__))
 		macify_name(lfname);
 #endif
-    FILE *fp=fopen(lfname,"wb");
-    if (fp) 
-    {
-    	fclose(fp);
-    	cfail=0;
+		FILE *fp=fopen(lfname,"wb");
+		if (fp)
+		{
+			fclose(fp);
+			cfail=0;
 		}
 #else
-    int fd=open(lfname,flags,S_IRWXU | S_IRWXG | S_IRWXO);     // can we get exclusive rights to this file?
-    if (fd<0) close(fd); else cfail=0;
+		int fd=open(lfname,flags,S_IRWXU | S_IRWXG | S_IRWXO);     // can we get exclusive rights to this file?
+		if (fd<0) close(fd); else cfail=0;
 #endif
 
-    if (cfail)
-      num++;
+		if (cfail)
+			num++;
 
-  } while (cfail && num<15);
-  if (cfail)
-  {
-    fprintf(stderr,"Error : Unable to open cache file for compiled code.\n"
-	    "        Please delete all files named lcacheXX.tmp\n"
-	    "        and make sure you have write permission to\n"
-	    "        directory (%s)\n",prefix);
-    exit(0);
-  } else
-  {
-    exit_proc(cache_cleanup,cache_cleanup2);    // make sure this file gets deleted on exit..
-  }
-  lcache_number=-1;
+	} while (cfail && num<15);
+
+	if (cfail)
+	{
+		fprintf(stderr,"Error : Unable to open cache file for compiled code.\n"
+			"        Please delete all files named lcacheXX.tmp\n"
+			"        and make sure you have write permission to\n"
+			"        directory (%s)\n",prefix);
+		exit(0);
+	}
+	else
+	{
+		exit_proc(cache_cleanup,cache_cleanup2);    // make sure this file gets deleted on exit..
+	}
+	lcache_number=-1;
 }
 
 cache_list::cache_list()
