@@ -3014,7 +3014,7 @@ void pal_win::close_window()
   }
 }
 
-#ifdef __POWERPC__
+#ifdef __MWERKS__
 #pragma global_optimizer on
 #endif
 
@@ -3047,7 +3047,7 @@ void pal_win::draw()
   }
 }
 
-#ifdef __POWERPC__
+#ifdef __MWERKS__
 #pragma global_optimizer reset
 #endif
 
