@@ -34,13 +34,18 @@
 #include "demo.hpp"
 #include "netcfg.hpp"
 
-#ifdef __POWERPC__
-#include <profiler.h>  //prof
-#endif
+//#ifdef __POWERPC__
+//#include <profiler.h>  //prof
+//#endif
 
 #include <ctype.h>
 #include <setjmp.h>
 
+#ifdef __APPLE__
+// SDL for OSX needs to override main()
+#include <SDL.h>
+#endif
+
 #define SHIFT_RIGHT_DEFAULT 0
 #define SHIFT_DOWN_DEFAULT 30
 
@@ -69,7 +74,7 @@ extern uchar chatting_enabled;
 
 extern int confirm_quit();
 
-#ifdef __POWERPC__
+#if (defined(__APPLE__) && !defined(__MACH__))
 extern char *macify_name(char *s);
 #endif
 
@@ -94,7 +99,7 @@ FILE *open_FILE(char *filename, char *mode)
   if (get_filename_prefix() && filename[0] != '/')
     sprintf(tmp_name,"%s%s",get_filename_prefix(),filename);
   else strcpy(tmp_name,filename);
-#ifdef __POWERPC__
+#if (defined(__APPLE__) && !defined(__MACH__))
   macify_name(tmp_name);
 #endif
   return fopen(tmp_name,mode);
@@ -2488,7 +2493,7 @@ void game_net_init(int argc, char **argv)
 
 }
 
-#ifdef __POWERPC__
+#if (defined(__APPLE__) && !defined(__MACH__))
 extern int PixMult;
 #if 1
 char cmdline[256];
@@ -2537,7 +2542,7 @@ void GetArgs(int &argc, char **(&argv))
 
 int main(int argc, char **argv)
 {
-#ifdef __POWERPC__
+#if (defined(__APPLE__) && !defined(__MACH__))
 	GetArgs(argc,argv);
 #endif
 
@@ -2562,9 +2567,9 @@ int main(int argc, char **argv)
 	jmalloc_init( 0x150000 );
 //  jmalloc_init(100000);
 
-#ifdef __POWERPC__
+#if (defined(__APPLE__) && !defined(__MACH__))
 	unsigned char km[16];
-	
+
 	fprintf(stderr,"Mac Options: ");
 	xres = 320; yres = 200;
 	GetKeys((unsigned long*)&km);
