@@ -9,12 +9,12 @@
 #include "jmalloc.hpp"
 #include <math.h>
 #include "dprint.hpp"
-#ifndef __POWERPC__
+#if (defined(__MACH__) || !defined(__APPLE__))
 #include <sys/types.h>
 #include <sys/stat.h>
 #endif
 
-#ifdef __POWERPC__
+#if (defined(__APPLE__) && !defined(__MACH__))
 extern char *macify_name(char *s);
 #endif
 
@@ -61,24 +61,30 @@ static int fast_load_mode = 0;
 
 void set_filename_prefix(char *prefix)
 {
-  if (spec_prefix) { jfree(spec_prefix); }
-  if (prefix) 
-  {
-    spec_prefix=strcpy((char *)jmalloc(strlen(prefix)+2,"prefix_name"),prefix);
-    int len=strlen(prefix);
-    if (prefix[len-1]!='\\' && prefix[len-1]!='/')
-    {
-      spec_prefix[len]='/';
-      spec_prefix[len+1]=0;
-    }
-  }
-
-  else spec_prefix=NULL;
+	if( spec_prefix )
+	{
+		jfree( spec_prefix );
+	}
+	
+	if( prefix )
+	{
+		spec_prefix = strcpy( (char *)jmalloc( strlen( prefix ) + 2, "prefix_name" ), prefix );
+		int len = strlen( prefix );
+		if( prefix[len - 1] != '\\' && prefix[len - 1] != '/')
+		{
+			spec_prefix[len] = '/';
+			spec_prefix[len + 1] = 0;
+		}
+	}
+	else
+	{
+		spec_prefix = NULL;
+	}
 }
 
 char *get_filename_prefix()
 {
-  return spec_prefix;
+	return spec_prefix;
 }
 
 
@@ -261,7 +267,7 @@ void set_spec_main_file(char *filename, int Search_order)
   strcpy(spec_main_file,filename);
   search_order=Search_order;
   
-#ifdef __POWERPC__
+#if (defined(__APPLE__) && !defined(__MACH__))
   spec_main_jfile.open_external(filename,"rb",O_BINARY|O_RDONLY);
   spec_main_fd = spec_main_jfile.get_fd();
   spec_main_sd.startup(&spec_main_jfile);
@@ -274,7 +280,7 @@ void set_spec_main_file(char *filename, int Search_order)
 
 void fast_load_start_recording(char *filename)
 {
-#ifdef __POWERPC__
+#if (defined(__APPLE__) && !defined(__MACH__))
   fast_load_fd = ::open(macify_name(filename),O_BINARY|O_CREAT|O_RDWR);
 #else
   fast_load_fd = ::open(filename,O_CREAT|O_RDWR,S_IRWXU | S_IRWXG | S_IRWXO);
@@ -289,7 +295,7 @@ void fast_load_stop_recording()
 
 void fast_load_start_reloading(char *filename)
 {
-#ifdef __POWERPC__
+#if (defined(__APPLE__) && !defined(__MACH__))
   fast_load_fd = ::open(macify_name(filename),O_BINARY|O_RDONLY);
 #else
   fast_load_fd = ::open(filename,O_RDONLY);
@@ -334,13 +340,13 @@ void jFILE::open_external(char *filename, char *mode, int flags)
     flags-=O_WRONLY;
     flags|=O_CREAT|O_RDWR;
 
-#ifdef __POWERPC__
-		fd=open(macify_name(tmp_name),flags);
+#if (defined(__APPLE__) && !defined(__MACH__))
+    fd=open(macify_name(tmp_name),flags);
 #else
     fd=open(tmp_name,flags,S_IRWXU | S_IRWXG | S_IRWXO);
 #endif
   } else 
-#ifdef __POWERPC__
+#if (defined(__APPLE__) && !defined(__MACH__))
     fd=open(macify_name(tmp_name),flags);
 #else
     fd=open(tmp_name,flags);
