@@ -19,7 +19,7 @@
 #include "nfserver.hpp"
 #include "lisp_gc.hpp"
 
-#ifndef __POWERPC__
+#if (defined(__MACH__) || !defined(__APPLE__))
 #include <sys/stat.h>
 #endif
 
@@ -2215,7 +2215,7 @@ int level::save(char *filename, int save_all)
 				jfree(buf);
 			}
 			delete bk;
-#ifndef __POWERPC__
+#if (defined(__MACH__) || !defined(__APPLE__))
 			chmod( bkname, S_IRWXU | S_IRWXG | S_IRWXO );
 #endif
 		}
@@ -2311,7 +2311,7 @@ int level::save(char *filename, int save_all)
 			}
 
 			delete fp;
-#ifndef __POWERPC__
+#if (defined(__MACH__) || !defined(__APPLE__))
 			chmod( name, S_IRWXU | S_IRWXG | S_IRWXO );
 #endif
 			write_cache_prof_info();
