@@ -696,86 +696,91 @@ ico_button *make_conditional_buttons(int x,int &y)
 
 void main_menu()
 {
-  int y=yres/2-100;
-  ico_button *list=make_conditional_buttons(xres-33,y);
-  list=make_default_buttons(xres-33,y,list);
+	int y=yres/2-100;
+	ico_button *list=make_conditional_buttons(xres-33,y);
+	list=make_default_buttons(xres-33,y,list);
 
+	input_manager *inm=new input_manager(screen,eh,list);
+	inm->allow_no_selections();
+	inm->clear_current();
 
-  input_manager *inm=new input_manager(screen,eh,list);
-  inm->allow_no_selections();
-  inm->clear_current();
+	screen->add_dirty(0,0,319,199);
 
-  screen->add_dirty(0,0,319,199);
+	event ev;
 
-  event ev;
-
-  int stop_menu=0;
-  time_marker start;
-  eh->flush_screen(); 
-  do
-  {
-    time_marker new_time;
-
-    if (eh->event_waiting())
-    {
-      do { eh->get_event(ev); } while (ev.type==EV_MOUSE_MOVE && eh->event_waiting()); 
-      inm->handle_event(ev,NULL,eh);
-      if (ev.type==EV_KEY && ev.key==JK_ESC)
-        eh->push_event(new event(ID_QUIT,NULL));
-
-      menu_handler(ev,inm);
-      start.get_time();
-      
-      eh->flush_screen();
-    } else {
-      // ECS - Added so that main menu doesn't grab 100% of CPU
-      milli_wait(30);
-    }
-
-
-    if (new_time.diff_time(&start)>10)
-    {
-      if (volume_window)
-        start.get_time();
-      else
-      {
-	if (!current_demo)
+	int stop_menu=0;
+	time_marker start;
+	eh->flush_screen(); 
+	do
 	{
-	  void *d=make_find_symbol("demos");
-	  if (DEFINEDP(symbol_value(d)))
-	  current_demo=symbol_value(d);
-	}
-	if (current_demo)
-	{
-	  demo_man.set_state(demo_manager::PLAYING,lstring_value(CAR(current_demo)));
-	  stop_menu=1;
-	  current_demo=CDR(current_demo);
-	}
-      }
-    }
+		time_marker new_time;
 
-    if (volume_window) stop_menu=0;  // can't exit with volume window open
-    else if (main_net_cfg && main_net_cfg->restart_state()) stop_menu=1;
-    else if (the_game->state==RUN_STATE) stop_menu=1;
-    else if (ev.type==EV_MESSAGE)
-    {
-      if (ev.message.id==ID_START_GAME || ev.message.id==ID_RETURN) stop_menu=1;
-      else if (ev.message.id==ID_QUIT)
-      {
-	if (confirm_quit()) stop_menu=1;
-	  else { ev.type=EV_SPURIOUS;       start.get_time(); }
-      }
-    }
+		if (eh->event_waiting())
+		{
+			do
+			{
+				eh->get_event(ev);
+			} while (ev.type==EV_MOUSE_MOVE && eh->event_waiting()); 
+			inm->handle_event(ev,NULL,eh);
+			if (ev.type==EV_KEY && ev.key==JK_ESC)
+				eh->push_event(new event(ID_QUIT,NULL));
 
-  } while (!stop_menu);
+			menu_handler(ev,inm);
+			start.get_time();
 
-  delete inm;
+			eh->flush_screen();
+		}
+		else
+		{
+			// ECS - Added so that main menu doesn't grab 100% of CPU
+			milli_wait(30);
+		}
 
+		if (new_time.diff_time(&start)>10)
+		{
+			if (volume_window)
+				start.get_time();
+			else
+			{
+				if (!current_demo)
+				{
+					void *d=make_find_symbol("demos");
+					if (DEFINEDP(symbol_value(d)))
+						current_demo=symbol_value(d);
+				}
+				if (current_demo)
+				{
+					demo_man.set_state(demo_manager::PLAYING,lstring_value(CAR(current_demo)));
+					stop_menu=1;
+					current_demo=CDR(current_demo);
+				}
+			}
+		}
 
-  if (ev.type==EV_MESSAGE && ev.message.id==ID_QUIT)   // propogate the quit message
-    the_game->end_session();
+		if (volume_window) stop_menu=0;  // can't exit with volume window open
+		else if (main_net_cfg && main_net_cfg->restart_state()) stop_menu=1;
+		else if (the_game->state==RUN_STATE) stop_menu=1;
+		else if (ev.type==EV_MESSAGE)
+		{
+			if (ev.message.id==ID_START_GAME || ev.message.id==ID_RETURN)
+				stop_menu=1;
+			else if (ev.message.id==ID_QUIT)
+			{
+				if (confirm_quit())
+					stop_menu=1;
+				else
+				{
+					ev.type=EV_SPURIOUS;
+					start.get_time();
+				}
+			}
+		}
+	} while (!stop_menu);
 
+	delete inm;
 
+	if (ev.type==EV_MESSAGE && ev.message.id==ID_QUIT)   // propogate the quit message
+		the_game->end_session();
 }
 
 
