@@ -1,3 +1,5 @@
+#include <sys/types.h>
+#include <stdio.h>
 #include <dirent.h>
 #include <stdlib.h>
 #include <string.h>
