@@ -4,6 +4,13 @@
 #include <time.h>
 #include "timing.hpp"
 
+#ifdef __APPLE__
+// OSX 10.1 has nanosleep but no header for it!
+extern "C" {
+int nanosleep(const struct timespec *rqtp, struct timespec *rmtp);
+}
+#endif
+
 // Constructor
 //
 time_marker::time_marker()
