@@ -172,7 +172,7 @@ char *get_login()
 {  if (cur_user_name[0]) return cur_user_name; else return "DOS user"; }
 
 #include <dos.h>
-#elif defined( __POWERPC__ )
+#elif defined( __APPLE__ )
 
 char *get_login()
 {  if (cur_user_name[0]) return cur_user_name; else return "Mac user"; }
